<p align="left">
  <a href="https://aeron7.github.io/nsepython/" target="_blank">
    <img width="300" src="https://github.com/aeron7/nsepython/blob/master/nsepython.png" alt="logo">
  </a>
</p>

#### NSEPython is a Python library to get publicly available data on the current [NSEIndia](nseindia.com)  site by communicating with their REST APIs.

<p align="left">
  <a href="https://aeron7.github.io/nsepython/" target="_blank">
    <img width="200" src="https://github.com/aeron7/nsepython/blob/master/button_read-the-documentation.png" alt="logo">
  </a>
</p>

## Installation

Use the package manager [pip](https://pypi.org/project/nsepython/) to install nsepython.

```bash
pip install nsepython
```
## Documentation

- Fetch All Indices.
- Fetch List of All FNO Stocks.
- Fetch Option Chain Data.
- An Advanced OI Chain Visualizer Function.
- Getting ATM Strikes.
- Stocks and Derivatives API Fetch Live Stock and Derivatives Prices and all detailed data.
- Holiday API
- Event Calendar API
- Results API
- Past Results API

## Contributing
For Discussion and Improving this Code, Join - https://www.unofficed.com/chat/

## License
[MIT](https://choosealicense.com/licenses/mit/)
